==> haskell-foldl-1.4.12-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.12
visibility:           public
id:                   foldl-1.4.12-5j9OefxiZuU20DYk5HlDT5
key:                  foldl-1.4.12-5j9OefxiZuU20DYk5HlDT5
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  af87cc710dd5160f0aa1501cdff59b43
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.0.1/site-local/foldl-1.4.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/foldl-1.4.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/foldl-1.4.12
hs-libraries:         HSfoldl-1.4.12-5j9OefxiZuU20DYk5HlDT5
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    comonad-5.0.8-FQMHC8Di1aZAOXOGXELcFI containers-0.6.4.1
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A
    hashable-1.3.4.0-6dnecuFViZBGFpHQwXe7GH
    primitive-0.7.2.0-LNBP19Yyt8R6V7t6f1oEAz
    profunctors-5.6.2-BCER5gcx0SlDcSUAEwXMiO
    random-1.2.1-AVlrOvJdpabLt5UKQZGZvR
    semigroupoids-5.3.6-8YyLw1xUGcxBRUiDY7goKe text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-FVdmWuNRiZiBPBGw5WvZRu
    vector-0.12.3.1-41pb7QyPIvSGm54QlMLBN3

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.12-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.12
visibility:           public
id:                   foldl-1.4.12-2EVLzEVGzpR6wEZczao2HX
key:                  foldl-1.4.12-2EVLzEVGzpR6wEZczao2HX
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  3708dc2879db89e24b657423da0ebf57
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.0.1/site-local/foldl-1.4.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/foldl-1.4.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/foldl-1.4.12
hs-libraries:         HSfoldl-1.4.12-2EVLzEVGzpR6wEZczao2HX
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    comonad-5.0.8-AsllVmCbjpcHyD8OOCrv5S containers-0.6.4.1
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A
    hashable-1.3.4.0-IEtvls2JnYMCj5AtMjw8bF
    primitive-0.7.2.0-H9HP2FbaY5C1JlRHDKja9P
    profunctors-5.6.2-JSpjDLFOHziFMPQ6l5NowS
    random-1.2.1-Iy7yOfCz74T6VyvkhFUFfX
    semigroupoids-5.3.6-JFZbW6XT2Qu838ghLJLro6 text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-7Twq3Q78XsnAV2eREMKYwX
    vector-0.12.3.1-HMAplmdcuCN6dtD8e6QGwL

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
